@@ -55,7 +55,7 @@ void on_about_activate (void)
        "GNU General Public License for more details."),
     N_("You should have received a copy of the GNU General Public License "
        "along with Sound Juicer; if not, write to the Free Software Foundation, Inc., "
-       "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA")
+       "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA")
   };
 
   license_trans = g_strconcat (_(license[0]), "\n\n",
